Changelog
=========


0.4.2 (2018-04-09)
------------------
- New version 0.4.2. [micpfist]
- Merge pull request #9 from pfitzer/pyup-update-youtube-
  dl-2018.3.20-to-2018.4.9. [Michael Pfister]

  Update youtube-dl to 2018.4.9
- Update youtube-dl from 2018.3.20 to 2018.4.9. [pyup-bot]
- Merge pull request #6 from pfitzer/pyup-update-youtube-
  dl-2018.3.14-to-2018.3.20. [Michael Pfister]

  Update youtube-dl to 2018.3.20
- Update youtube-dl from 2018.3.14 to 2018.3.20. [pyup-bot]
- Merge pull request #5 from pfitzer/pyup-update-youtube-
  dl-2018.3.10-to-2018.3.14. [Michael Pfister]

  Update youtube-dl to 2018.3.14
- Update youtube-dl from 2018.3.10 to 2018.3.14. [pyup-bot]
- Merge pull request #4 from pfitzer/pyup-update-youtube-
  dl-2018.3.3-to-2018.3.10. [Michael Pfister]

  Update youtube-dl to 2018.3.10
- Update youtube-dl from 2018.3.3 to 2018.3.10. [pyup-bot]
- Changede license cause of used mutagen. [pfitzer]
- Merge remote-tracking branch 'origin/master' [pfitzer]
- Merge pull request #3 from pfitzer/pyup-update-youtube-
  dl-2017.10.1-to-2018.3.3. [Michael Pfister]

  Update youtube-dl to 2018.3.3
- Merge branch 'master' into pyup-update-youtube-
  dl-2017.10.1-to-2018.3.3. [Michael Pfister]
- Update youtube-dl from 2017.10.1 to 2018.3.3. [pyup-bot]
- Readme. [pfitzer]
- Merge pull request #2 from pfitzer/pyup-update-mutagen-1.38-to-1.40.0.
  [Michael Pfister]

  Update mutagen to 1.40.0
- Update mutagen from 1.38 to 1.40.0. [pyup-bot]
- Pip requirements. [pfitzer]


0.4.1 (2017-10-04)
------------------
- Bugfix exception message. [pfitzer]
- Bugfix exception message. [pfitzer]
- Gitignore. [Michael Pfister]
- Python 3 compatible; pipenv for development. [Michael Pfister]


0.4.0 (2017-09-26)
------------------
- Python 3 compatible. [Michael Pfister]
- Changed documentation. [Michael Pfister]
- Added sphinx documentation. [Michael Pfister]
- Added pyc files to ignore. [Michael Pfister]
- Changelog. [Michael Pfister]


0.3.0 (2016-07-01)
------------------
- Class based. [Michael Pfister]
- Nicer readme. [Michael Pfister]


0.2.5 (2016-06-30)
------------------
- Bugfix: missing packages in setup.py. [Michael Pfister]
- Bugfix: missing packages in setup.py. [Michael Pfister]


0.2.4 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]


0.2.3 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]


0.2.2 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]
- Some cleaning. [Michael Pfister]
- Readme. [Michael Pfister]
- Readme. [Michael Pfister]


0.2.1 (2016-06-30)
------------------
- Pip naming conventions and version. [Michael Pfister]
- Pip naming conventions. [Michael Pfister]
- Format readme. [Michael Pfister]
- Format readme. [Michael Pfister]
- Initial commit. [Michael Pfister]


